@@ -1,4 +1,4 @@
-require 'Calendar.rb'
+require 'holiday_japan'
 require 'date'
 unless Time::new.respond_to?( :strftime_holiday_backup )
 then
@@ -7,8 +7,8 @@ then
    alias strftime_holiday_backup strftime
    def strftime( format )
     holiday = ""
-    day = Day.new(self.day,self.month,self.year,self.wday)
-    holiday = day.holiday_name_jp if day.holiday?
+    day = Date.new(self.year, self.month, self.day)
+    holiday = HolidayJapan.name(day) if HolidayJapan.check(day)
     strftime_holiday_backup( format.gsub( /%K/, holiday ) )
    end
   end
