@@ -44,15 +44,15 @@ describe "google_analytics plugin" do
 
 	def expected_html_footer_snippet
 		expected = <<-SCRIPT
-		<script>
-			(function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
-			(i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
-			m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
-			})(window,document,'script','//www.google-analytics.com/analytics.js','ga');
+			<!-- Global site tag (gtag.js) - Google Analytics -->
+			<script async src="https://www.googletagmanager.com/gtag/js?id=UA-53836-1"></script>
+			<script>
+				window.dataLayer = window.dataLayer || [];
+				function gtag(){dataLayer.push(arguments);}
+				gtag('js', new Date());
 
-			ga('create', 'UA-53836-1', 'auto');
-			ga('send', 'pageview');
-		// --></script>
+				gtag('config', 'UA-53836-1');
+			</script>
 		SCRIPT
 		expected.gsub( /^\t/, '' ).chomp
 	end
